module.exports = defineTest({
	description: 'tree-shake pure call expressions involving optional chaining'
});
